/**
 *****************************************************************************
 * Name: IteratorDemo
 * Description: This class holds the collection that is going to be traversed
 *              using Iterator instances. This corresponds to the class marked
 *              as Client in the structure diagram
 *
 * Note: This example is based on IBM's xml4j.
 *****************************************************************************
 */

import java.io.*;
import java.util.Enumeration;
import org.w3c.dom.*;
import com.ibm.xml.parser.*;

public class IteratorDemo {
    
    // This method uses the an Iterator to go through each node in the
    // collection (DOM).
    public static void traverseAll(AbstractIteratorIF i) {
	// Using the iterator, run through each node and print its value.
	for(i.next();!i.end();i.next())
	    System.out.println("--\nNode Name: "+i.getValue().getNodeName()
			       +" \nNodeValue: "+i.getValue().getNodeValue());

	// Exercise: use Command pattern to make extend the action possibilities as
	//           suggested in the article.
    }

    // Main slightly modified from xml4j docs.
    public static void main (String args[]) {

        String filename = null;
        if (args.length > 0) {
            filename = args[0];

            if (filename != null) {
                InputStream is;
                try {
                    is = new FileInputStream(filename);
                } catch (FileNotFoundException notFound) {
                    System.err.println(notFound);
                    return;
                }

                Parser parser = new Parser(filename);
                Document doc = parser.readStream(is);

                root = (Element)doc.getDocumentElement();
		
		LevelIterator myIterator = new LevelIterator(root);
                traverseAll(myIterator);
            }
        }
    } //Main
    private static Element root; // The root to our collection
}










